summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/H5MM.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5MM.c b/src/H5MM.c
index dc3cd2c..5626fdf 100644
--- a/src/H5MM.c
+++ b/src/H5MM.c
@@ -58,8 +58,8 @@ static int interface_initialize_g = 0;
void *
H5MM_malloc(size_t size)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT(H5MM_malloc);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5MM_malloc);
assert(size);
@@ -91,8 +91,8 @@ H5MM_malloc(size_t size)
void *
H5MM_calloc(size_t size)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT(H5MM_calloc);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5MM_calloc);
assert(size);